rm(list=ls())

library(coda)
library(rjags)
library(R2jags)

## note - the solution contains the full analysis for 'wrma'

## --------------------------------------------------
## load the data for all species
load(url('https://www.sfu.ca/~lmgonigl/materials-qm/data/occ-data.RData'),
     verbose=TRUE)

## --------------------------------------------------
## package data for JAGS (Boat-billed Flycatcher)
sp <- 'wrma'
my.data <- list(X=X[,,sp],
                nsite=nsite,
                forest=forest,
                nvisit=nvisit)
## --------------------------------------------------

## take a look at the data
head(my.data$X, 10)
my.data$nsite
my.data$forest
my.data$nvisit

## inits
my.inits <- function() {
  list(Z=rep(1,nrow(my.data$X)))
}

## model
my.model <- function() {

  ## PRIORS
  p ~ dunif(0,1)
  psi ~ dunif(0,1)
  
  ## LIKELIHOOD
  for(site in 1:nsite) {
    ## Occurrence
    Z[site] ~ dbern(psi)
    p.eff[site] <- Z[site] * p
    for(visit in 1:nvisit) {
      ## Detection 
      X[site,visit] ~ dbern(p.eff[site])
    }
  }

  ## Derived quantities
  num.occ <- sum(Z[]) ## Number of occupied sites
}

## parameters to track
my.params <- c('psi', 'p', 'num.occ')

res <- jags(data=my.data,
            inits=my.inits,
            parameters.to.save=my.params,
            model.file=my.model,
            n.iter=110000,
            n.burnin=10000,
            n.thin=10,
            n.chains=3,
            working.directory=NULL)

## to make life easier
bugs <- res$BUGSoutput
summ <- res$BUGSoutput$summary

## inspect output
columns <- c('mean','sd','2.5%','97.5%', 'Rhat')
summ[,columns]

## expit and logit functions
expit <- function(x) 1/(1+exp(-x))
logit <- function(x) log(x/(1-x))
